@@ -7,17 +7,13 @@ from tryceratops.violations import Violation
 from .exceptions import AnalyzerVisitException
 
 
-class BaseAnalyzer(ABC):
+class BaseAnalyzer(ABC, ast.NodeVisitor):
     EXPERIMENTAL = False
+    violation_code: Tuple[str, str]
 
     def __init__(self):
         self.violations: List[Violation] = []
 
-    @property
-    @abstractmethod
-    def violation_code() -> Tuple[str, str]:
-        pass
-
     def _mark_violation(self, *nodes):
         for node in nodes:
             self.violations.append(Violation.build(self.filename, self.violation_code, node))
@@ -45,7 +41,7 @@ def visit_error_handler(func):
     return _func
 
 
-class BaseRaiseCallableAnalyzer(BaseAnalyzer, ast.NodeVisitor, ABC):
+class BaseRaiseCallableAnalyzer(BaseAnalyzer, ABC):
     @abstractmethod
     def _check_raise_callable(self, node: ast.Raise, exc: ast.Call, func: ast.Name):
         pass
