@@ -1,13 +1,12 @@
 import ast
 import re
 import tokenize
-from io import TextIOWrapper
-from typing import Generator, Iterable, Tuple
+from typing import Generator, Iterable, TextIO, Tuple
 
 from tryceratops.filters import FileFilter, IgnoreViolation
 
-IGNORE_TRYCERATOPS_TOKEN = "notc"
-IGNORE_TOKEN_PATT = r"notc(: ?((TC\d{3},? ?)+))?"
+IGNORE_TRYCERATOPS_TOKEN = "noqa"
+IGNORE_TOKEN_PATT = r"noqa(: ?((TC\d{3},? ?)+))?"
 
 
 def _build_ignore_line(match: re.Match, location: Tuple[int, int]) -> IgnoreViolation:
@@ -29,14 +28,12 @@ def parse_ignore_tokens(
                 yield _build_ignore_line(match, start)
 
 
-def parse_ignore_comments_from_file(
-    content: TextIOWrapper,
-) -> Generator[IgnoreViolation, None, None]:
+def parse_ignore_comments_from_file(content: TextIO) -> Generator[IgnoreViolation, None, None]:
     tokens = tokenize.generate_tokens(content.readline)
     yield from parse_ignore_tokens(tokens)
 
 
-def parse_tree(content: TextIOWrapper) -> ast.AST:
+def parse_tree(content: TextIO) -> ast.AST:
     return ast.parse(content.read())
 
 
